.. _python3: https://www.python.org/download/releases/3.0

.. _Quadtree: https://en.wikipedia.org/wiki/Quadtree

.. _k-d-tree: https://en.wikipedia.org/wiki/K-d_tree

.. _bisection: https://en.wikipedia.org/wiki/Bisection_method

.. _great-circle: https://en.wikipedia.org/wiki/Great_circle

.. _pip: https://pypi.org

.. _uv: https://docs.astral.sh/uv

.. _haversine: https://en.wikipedia.org/wiki/Haversine_formula

.. _NumPy: https://numpy.org/

.. _polars: https://pola.rs/

.. _Jupyter: https://jupyter.org/

.. _NOC: https://noc.ac.uk
